searchData={"items":[{"type":"module","title":"Xogmios","doc":"This is the top level module for Xogmios. It implements functions to be used by client\nmodules that wish to connect with Ogmios.\n\nWhen used, the it expects one of the supported mini-protocols as argument. For example:\n\n    defmodule ChainSyncClient do\n      use Xogmios, :chain_sync\n      # ...\n    end\n\nor\n\n    defmodule StateQueryClient do\n      use Xogmios, :state_query\n      # ...\n    end","ref":"Xogmios.html"},{"type":"function","title":"Xogmios.start_chain_sync_link/2","doc":"Starts a new Chain Sync process linked to the current process.\n\nThe `sync_from` option can be passed as part of `opts` to define at which point\nthe chain should be synced from.\n\nThis option accepts either:\n\na) An atom from the list: `:origin`, `:byron`,\n`:shelley`, `:allegra`, `:mary`, `:alonzo`, `:babbage`.\n\nFor example:\n\n```elixir\ndef start_link(opts) do\n  initial_state = [sync_from: :babbage]\n  opts = Keyword.merge(opts, initial_state)\n  Xogmios.start_chain_sync_link(__MODULE__, opts)\nend\n```\n\nThis will sync with the chain starting from the first block of the Babbage era.\n\nb) A point in the chain, given its `slot` and `id`. For example:\n\n```elixir\ndef start_link(opts) do\n  initial_state = [\n    sync_from: %{\n      point: %{\n        slot: 114_127_654,\n        id: \"b0ff1e2bfc326a7f7378694b1f2693233058032bfb2798be2992a0db8b143099\"\n      }\n    }\n  ]\n  opts = Keyword.merge(opts, initial_state)\n  Xogmios.start_chain_sync_link(__MODULE__, opts)\nend\n```\n\nThis will sync with the chain starting from the first block **after** the specified point.\n\nAll other options passed as part of `opts` will be available in the `state` argument for `c:Xogmios.ChainSync.handle_block/2`.\nSee `ChainSyncClient` on this project's README for an example.","ref":"Xogmios.html#start_chain_sync_link/2"},{"type":"function","title":"Xogmios.start_state_link/2","doc":"Starts a new State Query process linked to the current process.\n\n`opts` are be passed to the underlying GenServer.","ref":"Xogmios.html#start_state_link/2"},{"type":"function","title":"Xogmios.start_tx_submission_link/2","doc":"Starts a new Tx Submission process linked to the current process.\n\n`opts` are be passed to the underlying GenServer.","ref":"Xogmios.html#start_tx_submission_link/2"},{"type":"behaviour","title":"Xogmios.ChainSync","doc":"This module interfaces with the Chain Synchronization protocol.","ref":"Xogmios.ChainSync.html"},{"type":"callback","title":"Xogmios.ChainSync.handle_block/2","doc":"Invoked when a new block is emitted. This callback is required.\n\nReturning `{:ok, :next_block, new_state}` will request the next block once it's made available.\n\nReturning `{:ok, new_state}` will not request anymore blocks.\n\nReturning `{:ok, :close, new_state}` will close the connection to the server.","ref":"Xogmios.ChainSync.html#c:handle_block/2"},{"type":"callback","title":"Xogmios.ChainSync.handle_connect/1","doc":"Invoked upon connecting to the server. This callback is optional.","ref":"Xogmios.ChainSync.html#c:handle_connect/1"},{"type":"callback","title":"Xogmios.ChainSync.handle_disconnect/2","doc":"Invoked upon disconnecting from the server. This callback is optional.\n\nReturning `{:ok, new_state}` will allow the connection to close.\n\nReturning `{:reconnect, interval_in_ms}` will attempt a reconnection after `interval_in_ms`","ref":"Xogmios.ChainSync.html#c:handle_disconnect/2"},{"type":"function","title":"Xogmios.ChainSync.start_link/2","doc":"Starts a new Chain Sync process linked to the current process.\n\nThis function should not be called directly, but rather via `Xogmios.start_chain_sync_link/2`","ref":"Xogmios.ChainSync.html#start_link/2"},{"type":"module","title":"Xogmios.ChainSync.Connection","doc":"This module implements a connection with the Ogmios Websocket server\nfor the Chain Synchronization protocol.","ref":"Xogmios.ChainSync.Connection.html"},{"type":"module","title":"Xogmios.ChainSync.Messages","doc":"This module contains messages for the Chain Synchronization protocol","ref":"Xogmios.ChainSync.Messages.html"},{"type":"function","title":"Xogmios.ChainSync.Messages.find_intersection/2","doc":"Syncs the client to the given point in the chain,\nindicated by `slot` and `id`.","ref":"Xogmios.ChainSync.Messages.html#find_intersection/2"},{"type":"function","title":"Xogmios.ChainSync.Messages.find_origin/0","doc":"Syncs the client to the origin of the chain.","ref":"Xogmios.ChainSync.Messages.html#find_origin/0"},{"type":"function","title":"Xogmios.ChainSync.Messages.last_block_from/1","doc":"Syncs with a particular era bound.\n\nValues accepted are `:shelley`,\n `:allegra`,\n `:mary`,\n `:alonzo`,\n `:babbage`\n\nThe client will sync with the first block of the given era.","ref":"Xogmios.ChainSync.Messages.html#last_block_from/1"},{"type":"function","title":"Xogmios.ChainSync.Messages.next_block/0","doc":"Request next block.","ref":"Xogmios.ChainSync.Messages.html#next_block/0"},{"type":"function","title":"Xogmios.ChainSync.Messages.next_block_start/0","doc":"Initial message to the server.\n\nOnce the response from this initial message is received, then\nthe client proceeds with the appropriate syncing strategy.","ref":"Xogmios.ChainSync.Messages.html#next_block_start/0"},{"type":"module","title":"Xogmios.StateQuery","doc":"This module interfaces with the State Query protocol.","ref":"Xogmios.StateQuery.html"},{"type":"function","title":"Xogmios.StateQuery.send_query/3","doc":"Sends a State Query call to the server and returns a response.\n\nThis function is synchronous and takes two arguments:\n\n1. (Optional) A process reference. If none given, it defaults to the linked process `__MODULE__`.\n2. The name of the query to run.\n3. (Optional) Parameters to the query.\n\nSupport for all [Ledger-state](https://ogmios.dev/mini-protocols/local-state-query/#ledger-state)\nand [Network](https://ogmios.dev/mini-protocols/local-state-query/#network) queries.\n\nFor Ledger-state queries, only the name of the query is needed. For example, the following\nfunction call\n\n```\nStateQuery.send_query(pid, \"epoch\")\n```\n\nis the same as calling\n\n```\nStateQuery.send_query(pid, \"queryLedgerState/epoch\")\n```\n\nFor Network queries, the prefix \"queryNetwork/\" is needed. For example:\n\n```\nStateQuery.send_query(pid, \"queryNetwork/blockHeight\")\n```\n\nOptional parameters are passed as the third argument:\n\n```\nquery_name = \"utxo\"\nquery_params = %{addresses: [address_1, address_2]}\nStateQuery.send_query(pid, query_name, query_params)\n```","ref":"Xogmios.StateQuery.html#send_query/3"},{"type":"function","title":"Xogmios.StateQuery.start_link/2","doc":"Starts a new State Query process linked to the current process.\n\nThis function should not be called directly, but rather via `Xogmios.start_state_link/2`","ref":"Xogmios.StateQuery.html#start_link/2"},{"type":"module","title":"Xogmios.StateQuery.Messages","doc":"This module contains messages for the State Query protocol","ref":"Xogmios.StateQuery.Messages.html"},{"type":"function","title":"Xogmios.StateQuery.Messages.build_message/3","doc":"Builds a message for a given scope, method and parameters.\n\n* The scope can be either `\"networkQuery\"` or `\"queryLedgerState\"`.\n* The method can be any of the supported methods from [Network](https://ogmios.dev/mini-protocols/local-state-query/#network) or\n[Ledger-state](https://ogmios.dev/mini-protocols/local-state-query/#ledger-state) scopes.\n* Parameters are optional, according to the method in question.","ref":"Xogmios.StateQuery.Messages.html#build_message/3"},{"type":"module","title":"Xogmios.TxSubmission","doc":"This module interfaces with the Tx Submission protocol.","ref":"Xogmios.TxSubmission.html"},{"type":"function","title":"Xogmios.TxSubmission.evaluate_tx/2","doc":"Evaluates the execution units of scripts present in a given transaction.\n\nThis function is synchronous and takes two arguments:\n\n1. (Optional) A process reference. If none given, it defaults to the linked process `__MODULE__`.\n2. The CBOR of a transaction. Unlike `submit_tx/1`, this function does not expect the transaction to be signed. Please refer to the [official Ogmios docs](https://ogmios.dev/mini-protocols/local-tx-submission/#evaluating-transactions) for more details on the type of transaction that is accepted.","ref":"Xogmios.TxSubmission.html#evaluate_tx/2"},{"type":"function","title":"Xogmios.TxSubmission.start_link/2","doc":"Starts a new Tx Submission process linked to the current process.\n\nThis function should not be called directly, but rather via `Xogmios.start_tx_submission_link/2`","ref":"Xogmios.TxSubmission.html#start_link/2"},{"type":"function","title":"Xogmios.TxSubmission.submit_tx/2","doc":"Submits a transaction to the server and returns a response including the transaction id.\n\nThis function is synchronous and takes two arguments:\n\n1. (Optional) A process reference. If none given, it defaults to the linked process `__MODULE__`.\n2. The CBOR of a signed transaction.","ref":"Xogmios.TxSubmission.html#submit_tx/2"},{"type":"module","title":"Xogmios.TxSubmission.Messages","doc":"This module contains messages for the Tx Submission protocol","ref":"Xogmios.TxSubmission.Messages.html"},{"type":"function","title":"Xogmios.TxSubmission.Messages.evaluate_tx/1","doc":"","ref":"Xogmios.TxSubmission.Messages.html#evaluate_tx/1"},{"type":"function","title":"Xogmios.TxSubmission.Messages.submit_tx/1","doc":"Submits signed transaction represented by given cbor argument","ref":"Xogmios.TxSubmission.Messages.html#submit_tx/1"},{"type":"extras","title":"Xogmios","doc":"# Xogmios\n\n![CI Status](https://github.com/wowica/xogmios/actions/workflows/ci.yml/badge.svg)\n[![Version](https://img.shields.io/hexpm/v/xogmios.svg)](https://hex.pm/packages/xogmios)\n\n[Docs](https://hexdocs.pm/xogmios/)\n\nAn Elixir client for [Ogmios](https://github.com/CardanoSolutions/ogmios).\n\n> Ogmios is a lightweight bridge interface for a Cardano node. It offers a WebSockets API that enables local clients to speak Ouroboros' mini-protocols via JSON/RPC. - https://ogmios.dev/\n\nMini-Protocols supported by this library:\n\n- [x] Chain Synchronization\n- [x] State Query\n- [x] Tx Submission\n- [ ] Mempool Monitoring\n\nSee [Examples](#examples) section below for information on how to use this library.","ref":"readme.html"},{"type":"extras","title":"Installing - Xogmios","doc":"Add the dependency to `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:xogmios, \"~> 0.3.0\"}\n  ]\nend\n```\n\nAdd your client modules to your application's supervision tree as such:\n\n```elixir\n# file: application.ex\ndef start(_type, _args) do\n  ogmios_url = System.fetch_env!(\"OGMIOS_URL\")\n\n  children = [\n    {ChainSyncClient, url: ogmios_url},\n    {StateQueryClient, url: ogmios_url},\n    {TxSubmissionClient, url: ogmios_url}\n  ]\n  #...\nend\n```\n\nThe value for the `url` option should be set to the address of your Ogmios instance.\n\nSee section below for examples of client modules.","ref":"readme.html#installing"},{"type":"extras","title":"Examples - Xogmios","doc":"#","ref":"readme.html#examples"},{"type":"extras","title":"Chain Sync - Xogmios","doc":"The following is an example of a module that implement the **Chain Sync** behaviour. In this example, the client syncs with the tip of the chain, reads the next 3 blocks and then closes the connection with the server.\n\n```elixir\ndefmodule ChainSyncClient do\n  use Xogmios, :chain_sync\n\n  def start_link(opts) do\n    initial_state = [counter: 3]\n    opts = Keyword.merge(opts, initial_state)\n    Xogmios.start_chain_sync_link(__MODULE__, opts)\n  end\n\n  @impl true\n  def handle_block(block, %{counter: counter} = state) when counter > 1 do\n    IO.puts(\"handle_block #{block[\"height\"]}\")\n    {:ok, :next_block, %{state | counter: counter - 1}}\n  end\n\n  @impl true\n  def handle_block(block, state) do\n    IO.puts(\"final handle_block #{block[\"height\"]}\")\n    {:close, state}\n  end\nend\n```\n\n#","ref":"readme.html#chain-sync"},{"type":"extras","title":"State Query - Xogmios","doc":"The following illustrates working with the **State Query** protocol. It runs queries against the tip of the chain.\n\n```elixir\ndefmodule StateQueryClient do\n  use Xogmios, :state_query\n  alias Xogmios.StateQuery\n\n  def start_link(opts) do\n    Xogmios.start_state_link(__MODULE__, opts)\n  end\n\n  def get_current_epoch(pid \\\\ __MODULE__) do\n    # Defaults to Ledger-state queries.\n    # The following call is the same as calling\n    # `StateQuery.send_query(pid, \"queryLedgerState/epoch\")`\n    StateQuery.send_query(pid, \"epoch\")\n  end\n\n  def get_network_height(pid \\\\ __MODULE__) do\n    # For network queries, scope must be explicitly used.\n    StateQuery.send_query(pid, \"queryNetwork/blockHeight\")`\n  end\n\n  def send_query_no_params(pid \\\\ __MODULE__, query_name) do\n    StateQuery.send_query(pid, query_name)\n  end\n\n  def send_query(pid \\\\ __MODULE__, query_name, query_params) do\n    # Optional query params are sent as the third argument\n    # to StateQuery.send_query/3\n    StateQuery.send_query(pid, query_name, query_params)\n  end\nend\n```\n\n#","ref":"readme.html#state-query"},{"type":"extras","title":"Tx Submission - Xogmios","doc":"The following illustrates working with the **Transaction Submission** protocol. It submits a signed transaction, represented as a CBOR, to the Ogmios server.\n\n```elixir\ndefmodule TxSubmissionClient do\n  use Xogmios, :tx_submission\n  alias Xogmios.TxSubmission\n\n  def start_link(opts) do\n    Xogmios.start_tx_submission_link(__MODULE__, opts)\n  end\n\n  def submit_tx(pid \\\\ __MODULE__, cbor) do\n    # The CBOR must be a valid transaction,\n    # properly built and signed\n    TxSubmission.submit_tx(pid, cbor)\n  end\nend\n```\n\nFor examples of applications using this library, see [Blocks](https://github.com/wowica/blocks) and [xogmios_watcher](https://github.com/wowica/xogmios_watcher).","ref":"readme.html#tx-submission"},{"type":"extras","title":"Test - Xogmios","doc":"Run `mix test`. Tests do NOT rely on a running Ogmios instance.","ref":"readme.html#test"}],"content_type":"text/markdown"}